===============================
Roman Numeral Converter
===============================

.. image:: https://badge.fury.io/py/romans.png
    :target: http://badge.fury.io/py/romans

.. image:: https://travis-ci.org/drincruz/romans.png?branch=master
        :target: https://travis-ci.org/drincruz/romans

.. image:: https://pypip.in/d/romans/badge.png
        :target: https://pypi.python.org/pypi/romans


Roman Numeral Converter converts Roman numerals.

* Free software: MIT license
* Documentation: https://romans.readthedocs.org.

Features
--------

* TODO